@@ -54,18 +54,16 @@ module Codec.Compression.Zlib.Internal (
   decompressWithErrors,
   DecompressStream(..),
   DecompressError(..),
+  foldDecompressStream,
+  fromDecompressStream,
   ) where
 
 import Prelude hiding (length)
 import Control.Monad (when)
 import Control.Exception (assert)
 import qualified Data.ByteString.Lazy as L
-#ifdef BYTESTRING_IN_BASE
-import qualified Data.ByteString.Base as S
-#else
 import qualified Data.ByteString.Lazy.Internal as L
 import qualified Data.ByteString.Internal as S
-#endif
 
 import qualified Codec.Compression.Zlib.Stream as Stream
 import Codec.Compression.Zlib.Stream (Stream)
@@ -139,13 +137,8 @@ defaultDecompressParams = DecompressParams {
 -- are 16k and 32k respectively (less a small accounting overhead).
 --
 defaultCompressBufferSize, defaultDecompressBufferSize :: Int
-#ifdef BYTESTRING_IN_BASE
-defaultCompressBufferSize   = 16 * 1024 - 16
-defaultDecompressBufferSize = 32 * 1024 - 16
-#else
 defaultCompressBufferSize   = 16 * 1024 - L.chunkOverhead
 defaultDecompressBufferSize = 32 * 1024 - L.chunkOverhead
-#endif
 
 -- | A sequence of chunks of data produced from decompression.
 --
@@ -181,7 +174,8 @@ data DecompressError =
    | DataError
 
 -- | Fold an 'DecompressionStream'. Just like 'foldr' but with an extra error
--- case. For example to convert to a list and translate the errors into exceptions:
+-- case. For example to convert to a list and translate the errors into
+-- exceptions:
 --
 -- > foldDecompressStream (:) [] (\code msg -> error msg)
 --
@@ -194,11 +188,19 @@ foldDecompressStream chunk end err = fold
     fold (StreamChunk bs stream) = chunk bs (fold stream)
     fold (StreamError code msg)  = err code msg
 
+-- | Convert a 'DecompressStream' to a lazy 'ByteString'. If any decompression
+-- errors are encountered then they are thrown as exceptions.
+--
+-- This is a special case of 'foldDecompressStream'.
+--
 fromDecompressStream :: DecompressStream -> L.ByteString
 fromDecompressStream =
   foldDecompressStream L.Chunk L.Empty
     (\_code msg -> error ("Codec.Compression.Zlib: " ++ msg))
 
+--TODO: throw DecompressError as an Exception class type and document that it
+-- does this.
+
 -- | Compress a data stream.
 --
 -- There are no expected error conditions. All input data streams are valid. It
